from setuptools import setup

setup(name='mitro_distributions_test',
      version='0.1',
      description='Gaussian distributions',
      packages=['mitro_distributions_test'],
      zip_safe=False)
